@@ -62,7 +62,7 @@ sub stc_build_scintilla_object {
 		'-O2',
 		'-Wall',
 		$object_name !~ /((Plat|Scintilla)WX|scintilla)\.o/
-		? '-Wno-missing-braces -Wno-char-subscripts -pedantic'
+		? '-Wno-missing-braces -Wno-char-subscripts'
 		: '',
 		join( ' ', @$includedirs ),
 		$module,
@@ -91,6 +91,9 @@ sub stc_link_scintilla_objects {
 sub stc_build_xs {
 	my ($self) = @_;
 
+	# Do not build XS if it is up to date
+	return if $self->up_to_date( 'Scintilla.c', 'Scintilla.o' );
+
 	my $dist_version = $self->dist_version;
 
 	# we must remove any nostdinc params
