@@ -5,10 +5,13 @@ use warnings;
 use Wx;
 use Carp;
 
-our $VERSION = '0.20';
+our $VERSION = '0.22';
 
 # Define Perl 6 lexer
-use constant wxSCINTILLA_LEX_PERL6 => 98;
+use constant wxSCINTILLA_LEX_PERL6  => 102;
+use constant wxSCINTILLA_P6_DEFAULT => 0;
+use constant wxSCINTILLA_P6_COMMENT => 1;
+use constant wxSCINTILLA_P6_STRING  => 2;
 
 # check for loaded Wx::STC
 if ( exists( $INC{'Wx/STC.pm'} ) ) {
@@ -25,11 +28,11 @@ XSLoader::load 'Wx::Scintilla', $VERSION;
 no strict;
 
 package Wx::ScintillaTextCtrl;
-our $VERSION = '0.20';
+our $VERSION = '0.22';
 @ISA = qw(Wx::Control);
 
 package Wx::ScintillaTextEvent;
-our $VERSION = '0.20';
+our $VERSION = '0.22';
 @ISA = qw(Wx::CommandEvent);
 
 #Defeat the indexer by splitting the package declaration on two lines
@@ -189,9 +192,7 @@ Note: You cannot load Wx::STC and Wx::Scintilla in the same application. They
 are mutually exclusive. The wxSTC_... events are handled by one library or
 the other.
 
-You can enable experimental building of scintilla 2.03 via the following command:
-
-    perl Build.PL --stc2
+Scintilla 2.28 is now bundled and enabled by default.
 
 =head1 MANUAL
 
@@ -215,7 +216,7 @@ L<http://wiki.wxperl.info/w/index.php/Mac_OS_X_Platform_Notes> for more informat
 
 wxWidgets 2.9.1 and development have Scintilla 2.03 so far. I searched for Perl lexer
 changes in scintilla history and here is what we will be getting when we upgrade to
-2.20+.
+2.26+.
 
 =over
 
@@ -229,7 +230,7 @@ fold.perl.comment.explicit. Fold structure for Perl fixed.
 Perl folder works for array blocks, adjacent package statements, nested PODs,
 and terminates package folding at DATA, D and Z.
 
-=item Release 1.79 (Currently we're here)
+=item Release 1.79
 
 Perl lexer bug fixed where previous lexical states persisted causing "/" special 
 case styling and subroutine prototype styling to not be correct.
